Promus Documentation — promus 0.7b6 documentation

### Navigation

- index
- next |
- promus 0.7b6 documentation »

# Promus Documentation

Promus is a remote manager designed to create and manage git repositories in a remote server without the need of admin privileges.

## Basic Usage

- What is Promus?
- Installation
  - The Easy Way
  - Installing on *nix Systems
  - Git
  - Promus Script
  - Setting up promus
- Getting Started with Promus
  - Password-less Connection To Server
  - Send a Collaboration Request
  - Accepting a Collaboration Request
  - Initializing a Repository

### Navigation

- index
- next |
- promus 0.7b6 documentation »